@@ -7,7 +7,7 @@
     Add to your Cargo.toml:
     ```toml
     [dependencies]
-    fltk-egui = "0.3"
+    fltk-egui = "0.5" # targets egui 0.16
     ```
 
     The basic premise is that egui is an immediate mode gui, while FLTK is retained.
@@ -29,15 +29,13 @@
 
 use std::time::Instant;
 
-use chrono::Timelike;
 // Re-export dependencies.
 pub use egui;
-use egui::{pos2, CursorIcon, Event, Key, Modifiers, Pos2, RawInput};
-pub use epi;
+use egui::{pos2, CursorIcon, Event, Key, Modifiers, Pos2, RawInput, Vec2};
 pub use fltk;
 use fltk::{
     app, enums,
-    prelude::{FltkError, ImageExt, InputExt, WidgetExt, WindowExt},
+    prelude::{FltkError, GroupExt, ImageExt, InputExt, WidgetExt, WindowExt},
     window::GlWindow,
 };
 pub use gl;
@@ -51,34 +49,17 @@ pub fn with_fltk(win: &mut GlWindow, scale: DpiScaling) -> (Painter, EguiInputSt
         DpiScaling::Default => win.pixels_per_unit(),
         DpiScaling::Custom(custom) => custom,
     };
+    let inp = fltk::input::Input::default();
     let painter = Painter::new(win, scale);
+    win.add(&inp);
     EguiInputState::new(painter)
 }
-/// Time of day as seconds since midnight. Used for clock in demo app.
-pub fn get_seconds_since_midnight() -> f64 {
-    let time = chrono::Local::now().time();
-    time.num_seconds_from_midnight() as f64 + 1e-9 * (time.nanosecond() as f64)
-}
 
 /// Frame time for FPS.
 pub fn get_frame_time(start_time: Instant) -> f32 {
     (Instant::now() - start_time).as_secs_f64() as f32
 }
 
-/// Repaint signal for epi frame.
-pub struct Signal;
-impl Default for Signal {
-    fn default() -> Self {
-        Self {}
-    }
-}
-
-impl epi::RepaintSignal for Signal {
-    fn request_repaint(&self) {
-        ()
-    }
-}
-
 /// The scaling factors of the app
 pub enum DpiScaling {
     /// Default DPI Scale by fltk, usually 1.0
@@ -162,7 +143,6 @@ pub fn input_to_egui(
     state: &mut EguiInputState,
     painter: &mut Painter,
 ) {
-    let inp = fltk::input::Input::default();
     let (x, y) = app::event_coords();
     let pixels_per_point = painter.pixels_per_point;
     match event {
@@ -229,6 +209,7 @@ pub fn input_to_egui(
                     command: (keymod & enums::EventState::Command == enums::EventState::Command),
                 };
                 if state.modifiers.command && key == Key::V {
+                    let inp: fltk::input::Input = unsafe { win.child(0).unwrap().into_widget() };
                     app::paste(&inp);
                     state.input.events.push(Event::Text(inp.value()));
                 }
@@ -283,10 +264,10 @@ pub fn input_to_egui(
                 let zoom_factor = 1.2;
                 match app::event_dy() {
                     app::MouseWheel::Up => {
-                        state.input.zoom_delta /= zoom_factor;
+                        state.input.events.push(Event::Zoom(zoom_factor * -1.0));
                     }
                     app::MouseWheel::Down => {
-                        state.input.zoom_delta *= zoom_factor;
+                        state.input.events.push(Event::Zoom(zoom_factor));
                     }
                     _ => (),
                 }
@@ -294,10 +275,16 @@ pub fn input_to_egui(
                 let scroll_factor = 15.0;
                 match app::event_dy() {
                     app::MouseWheel::Up => {
-                        state.input.scroll_delta.y -= scroll_factor;
+                        state.input.events.push(Event::Scroll(Vec2 {
+                            x: scroll_factor,
+                            y: 0.,
+                        }));
                     }
                     app::MouseWheel::Down => {
-                        state.input.scroll_delta.y += scroll_factor;
+                        state.input.events.push(Event::Scroll(Vec2 {
+                            x: 0.,
+                            y: scroll_factor,
+                        }));
                     }
                     _ => (),
                 }
