@@ -12,7 +12,7 @@ use std::ffi::CString;
 use std::os::raw::c_void;
 
 use egui::{
-    paint::{Color32, Mesh, Texture},
+    epaint::{Color32, FontImage, Mesh},
     vec2, ClippedMesh, Pos2, Rect,
 };
 
@@ -301,7 +301,7 @@ impl Painter {
         id
     }
 
-    fn upload_egui_texture(&mut self, texture: &Texture) {
+    fn upload_egui_texture(&mut self, texture: &FontImage) {
         if self.egui_texture_version == Some(texture.version) {
             return; // No change
         }
@@ -462,8 +462,8 @@ impl Painter {
     }
 
     /// Frees the user texture,
-    /// 
-    /// fn free_user_texture() and fn free() implemented from epi both are basically the same. 
+    ///
+    /// fn free_user_texture() and fn free() implemented from epi both are basically the same.
     pub fn free_user_texture(&mut self, id: egui::TextureId) {
         if let egui::TextureId::User(id) = id {
             let idx = id as usize;
@@ -485,7 +485,7 @@ impl Painter {
         &mut self,
         bg_color: Option<Color32>,
         meshes: Vec<ClippedMesh>,
-        egui_texture: &Texture,
+        egui_texture: &FontImage,
     ) {
         self.upload_egui_texture(egui_texture);
         self.upload_user_textures();
@@ -566,7 +566,6 @@ impl Painter {
             let indices: Vec<u16> = mesh.indices.iter().map(move |idx| *idx as u16).collect();
             let indices_len = indices.len();
             let vertices = &mesh.vertices;
-            let vertices_len = vertices.len();
 
             // --------------------------------------------------------------------
 
@@ -582,10 +581,10 @@ impl Painter {
 
             // --------------------------------------------------------------------
 
-            let mut positions: Vec<f32> = Vec::with_capacity(2 * vertices_len);
-            let mut tex_coords: Vec<f32> = Vec::with_capacity(2 * vertices_len);
+            let mut positions: Vec<f32> = Vec::with_capacity(2 * indices_len);
+            let mut tex_coords: Vec<f32> = Vec::with_capacity(2 * indices_len);
             {
-                for v in &mesh.vertices {
+                for v in vertices {
                     positions.push(v.pos.x);
                     positions.push(v.pos.y);
                     tex_coords.push(v.uv.x);
@@ -637,7 +636,7 @@ impl Painter {
 
             // --------------------------------------------------------------------
 
-            let mut colors: Vec<u8> = Vec::with_capacity(4 * vertices_len);
+            let mut colors: Vec<u8> = Vec::with_capacity(4 * indices_len);
             {
                 for v in vertices {
                     colors.push(v.color[0]);
@@ -708,20 +707,6 @@ impl Painter {
     }
 }
 
-impl epi::TextureAllocator for Painter {
-    fn alloc_srgba_premultiplied(
-        &mut self,
-        size: (usize, usize),
-        srgba_pixels: &[egui::Color32],
-    ) -> egui::TextureId {
-        self.new_user_texture(size, srgba_pixels, true)
-    }
-
-    fn free(&mut self, id: egui::TextureId) {
-        self.free_user_texture(id)
-    }
-}
-
 impl Drop for Painter {
     fn drop(&mut self) {
         self.cleanup()
